* Encoding: UTF-8.
* Note: Replace "...PATH..." with the path to the logfile!.
GET DATA
  /TYPE=TXT
  /FILE="...PATH...\Pfister_et_al_2013_PsySci_Exp1_Raw.dat"
  /DELCASE=LINE
  /DELIMITERS="\t"
  /ARRANGEMENT=DELIMITED
  /FIRSTCASE=2
  /IMPORTCASE=ALL
  /VARIABLES=
  Participant_Pair F2.0
  Model F2.0
  Imitator F2.0
  Part F1.0
  Block F1.0
  Blocktrial F2.0
  Trial F3.0
  Compatibility F2.0
  RT1 F4.0
  R1_CDuration F1.0
  R1_Duration F3.0
  R1_ACC F1.0
  R1_ErrorType F3.0
  RT2 F3.0
  RT2_Cor F4.0
  R2_CDuration F1.0
  R2_Duration F3.0
  R2_ACC F3.0
  R2_ErrorType F3.0
  Trial_ACC F1.0
  Trial_ACC_N1 F3.0.
CACHE.
EXECUTE.
DATASET NAME SozRE WINDOW=FRONT.



*Set RT and error filters.
USE ALL.
COMPUTE errorfilter1=((Block ~= 1) & (Block ~= 6) & (Block ~= 11) & (Block ~= 16)).
VALUE LABELS errorfilter1 0 'Not Selected' 1 'Selected'.
FORMATS errorfilter1 (f1.0).
FILTER BY errorfilter1.
EXECUTE.

USE ALL.
COMPUTE errorfilter2=((Block ~= 1) & (Block ~= 6) & (Block ~= 11) & (Block ~= 16) & (R1_ACC = 1)).
VALUE LABELS errorfilter2 0 'Not Selected' 1 'Selected'.
FORMATS errorfilter2 (f1.0).
FILTER BY errorfilter2.
EXECUTE.


USE ALL.
COMPUTE megafilter=((Block ~= 1) & (Block ~= 6) & (Block ~= 11) & (Block ~= 16) & (Trial_ACC = 1)).
VALUE LABELS megafilter 0 'Not Selected' 1 'Selected'.
FORMATS megafilter (f1.0).
FILTER BY megafilter.
EXECUTE.

SORT CASES BY Compatibility. 
SPLIT FILE SEPARATE BY Compatibility.

DELETE VARIABLES ZRT1 ZR1_Duration ZRT2 ZR2_Duration.
SORT CASES  BY Model Compatibility.
SPLIT FILE SEPARATE BY Model Compatibility.


DESCRIPTIVES VARIABLES=RT1 R1_Duration RT2 R2_Duration
  /SAVE
  /STATISTICS=MEAN STDDEV MIN MAX.


SPLIT FILE OFF.
SORT CASES BY Participant_Pair(A) Model(A) Part(A) Block(A) Blocktrial(A).

USE ALL.
FILTER BY megafilter.
EXECUTE.

RECODE ZRT1 ZRT2 (MISSING=SYSMIS) (-2.5 thru 2.5=0) (ELSE=1) INTO Outlier1 Outlier2.
EXECUTE.

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=Model Outlier1 Outlier2 DISPLAY=LABEL
  /TABLE Model [C][COUNT F40.0] BY Outlier1 [C] + Outlier2 [C]
  /CATEGORIES VARIABLES=Model Outlier1 Outlier2 ORDER=A KEY=VALUE EMPTY=EXCLUDE.


************************************************************************************************************************************************************************.
* Get model R-E data ***********************************************************************************************************************************************.
************************************************************************************************************************************************************************.

USE ALL.
COMPUTE zfilter=((megafilter = 1) & (ABS(ZRT1)<2.5)).
VALUE LABELS zfilter 0 'Not Selected' 1 'Selected'.
FORMATS zfilter (f1.0).
FILTER BY zfilter.
EXECUTE.

DATASET DECLARE Soz_RE_Aggr.
AGGREGATE
  /OUTFILE='Soz_RE_Aggr'
  /BREAK=Model Compatibility
  /RT1=MEAN(RT1) 
  /R1_Duration=MEAN(R1_Duration) .

DATASET ACTIVATE Soz_RE_Aggr.

COMPUTE Compatibility_Corr = Compatibility + 1.
EXECUTE. 

SORT CASES BY Model Compatibility_Corr.
CASESTOVARS
  /ID=Model
  /INDEX=Compatibility_Corr
  /GROUPBY=VARIABLE.



************************************************************************************************************************************************************************.
* Get model R-E data: errors ***************************************************************************************************************************************.
************************************************************************************************************************************************************************.
DATASET ACTIVATE SozRE.

USE ALL.
COMPUTE zfilter=((errorfilter1 = 1) & (R1_ACC = 0)).
VALUE LABELS zfilter 0 'Not Selected' 1 'Selected'.
FORMATS zfilter (f1.0).
FILTER BY zfilter.
EXECUTE.

DATASET DECLARE Soz_RE_Aggr_tmp.
AGGREGATE
  /OUTFILE='Soz_RE_Aggr_tmp'
  /BREAK=Model Compatibility
  /NR1=N(RT1).

DATASET ACTIVATE Soz_RE_Aggr_tmp.

COMPUTE Compatibility_Corr = Compatibility + 1.
EXECUTE. 

SORT CASES BY Model Compatibility_Corr.
CASESTOVARS
  /ID=Model
  /INDEX=Compatibility_Corr
  /GROUPBY=VARIABLE.

RECODE NR1..00 NR1.2.00 (MISSING=0).
EXECUTE.


DATASET ACTIVATE Soz_RE_Aggr.

MATCH FILES /FILE=*
  /FILE='Soz_RE_Aggr_tmp'
  /RENAME (Compatibility..00 Compatibility.2.00 = d2 d3) 
  /DROP= d2 d3.
EXECUTE.

DATASET CLOSE Soz_RE_Aggr_tmp.




************************************************************************************************************************************************************************.
* Get model R-E data: Nerrors *************************************************************************************************************************************.
************************************************************************************************************************************************************************.
DATASET ACTIVATE SozRE.

USE ALL.
COMPUTE zfilter=((errorfilter1 = 1)).
VALUE LABELS zfilter 0 'Not Selected' 1 'Selected'.
FORMATS zfilter (f1.0).
FILTER BY zfilter.
EXECUTE.

DATASET DECLARE Soz_RE_Aggr_tmp.
AGGREGATE
  /OUTFILE='Soz_RE_Aggr_tmp'
  /BREAK=Model Compatibility
  /MR1=N(RT1).

DATASET ACTIVATE Soz_RE_Aggr_tmp.

COMPUTE Compatibility_Corr = Compatibility + 1.
EXECUTE. 


SORT CASES BY Model Compatibility_Corr.
CASESTOVARS
  /ID=Model
  /INDEX=Compatibility_Corr
  /GROUPBY=VARIABLE.

DATASET ACTIVATE Soz_RE_Aggr.

MATCH FILES /FILE=*
  /FILE='Soz_RE_Aggr_tmp'
  /RENAME (Compatibility..00 Compatibility.2.00 = d2 d3) 
  /DROP= d2 d3.
EXECUTE.

DATASET CLOSE Soz_RE_Aggr_tmp.









************************************************************************************************************************************************************************.
* Get imitator S-R data *********************************************************************************************************************************************.
************************************************************************************************************************************************************************.
DATASET ACTIVATE SozRE.

USE ALL.
COMPUTE zfilter=((megafilter = 1) & (ABS(ZRT2)<2.5)).
VALUE LABELS zfilter 0 'Not Selected' 1 'Selected'.
FORMATS zfilter (f1.0).
FILTER BY zfilter.
EXECUTE.

DATASET DECLARE Soz_RE_Aggr_tmp.
AGGREGATE
  /OUTFILE='Soz_RE_Aggr_tmp'
  /BREAK=Imitator Compatibility
  /RT2=MEAN(RT2) 
  /R2_Duration=MEAN(R2_Duration).

DATASET ACTIVATE Soz_RE_Aggr_tmp.

COMPUTE Compatibility_Corr = Compatibility + 1.
EXECUTE. 

SORT CASES BY Imitator Compatibility_Corr.
CASESTOVARS
  /ID=Imitator
  /INDEX=Compatibility_Corr
  /GROUPBY=VARIABLE.


DATASET ACTIVATE Soz_RE_Aggr.

MATCH FILES /FILE=*
  /RENAME (Compatibility..00 Compatibility.2.00 = d0 d1) 
  /FILE='Soz_RE_Aggr_tmp'
  /RENAME (Compatibility..00 Compatibility.2.00 = d2 d3) 
  /DROP= d0 d1 d2 d3.
EXECUTE.

DATASET CLOSE Soz_RE_Aggr_tmp.



************************************************************************************************************************************************************************.
* Get imitator S-R data: errors *************************************************************************************************************************************.
************************************************************************************************************************************************************************.
DATASET ACTIVATE SozRE.

USE ALL.
COMPUTE zfilter=((errorfilter2= 1) & (R2_ACC = 0)).
VALUE LABELS zfilter 0 'Not Selected' 1 'Selected'.
FORMATS zfilter (f1.0).
FILTER BY zfilter.
EXECUTE.

DATASET DECLARE Soz_RE_Aggr_tmp.
AGGREGATE
  /OUTFILE='Soz_RE_Aggr_tmp'
  /BREAK=Imitator Compatibility
  /NR2=N(RT2).

DATASET ACTIVATE Soz_RE_Aggr_tmp.

COMPUTE Compatibility_Corr = Compatibility + 1.
EXECUTE. 

RECODE NR2 (MISSING=0).
EXECUTE.

SORT CASES BY Imitator Compatibility_Corr.
CASESTOVARS
  /ID=Imitator
  /INDEX=Compatibility_Corr
  /GROUPBY=VARIABLE.

RECODE NR2..00 NR2.2.00 (MISSING=0).
EXECUTE.

DATASET ACTIVATE Soz_RE_Aggr.

MATCH FILES /FILE=*
  /FILE='Soz_RE_Aggr_tmp'
  /RENAME (Compatibility..00 Compatibility.2.00 = d2 d3) 
  /DROP= d2 d3.
EXECUTE.

DATASET CLOSE Soz_RE_Aggr_tmp.



************************************************************************************************************************************************************************.
* Get imitator S-R data: Nerrors ***********************************************************************************************************************************.
************************************************************************************************************************************************************************.
DATASET ACTIVATE SozRE.

USE ALL.
COMPUTE zfilter=((errorfilter2 = 1)).
VALUE LABELS zfilter 0 'Not Selected' 1 'Selected'.
FORMATS zfilter (f1.0).
FILTER BY zfilter.
EXECUTE.

DATASET DECLARE Soz_RE_Aggr_tmp.
AGGREGATE
  /OUTFILE='Soz_RE_Aggr_tmp'
  /BREAK=Imitator Compatibility
  /MR2=N(RT2).

DATASET ACTIVATE Soz_RE_Aggr_tmp.

COMPUTE Compatibility_Corr = Compatibility + 1.
EXECUTE. 


SORT CASES BY Imitator Compatibility_Corr.
CASESTOVARS
  /ID=Imitator
  /INDEX=Compatibility_Corr
  /GROUPBY=VARIABLE.

DATASET ACTIVATE Soz_RE_Aggr.

MATCH FILES /FILE=*
  /FILE='Soz_RE_Aggr_tmp'
  /RENAME (Compatibility..00 Compatibility.2.00 = d2 d3) 
  /DROP= d2 d3.
EXECUTE.

DATASET CLOSE Soz_RE_Aggr_tmp.



************************************************************************************************************************************************************************.
* Clean up dataset **************************************************************************************************************************************************.
************************************************************************************************************************************************************************.
DATASET ACTIVATE Soz_RE_Aggr.

COMPUTE NR1..00 = NR1..00 / MR1 * 100.
COMPUTE NR1.2.00 = NR1.2.00 / MR1 * 100.
EXECUTE.



COMPUTE NR2..00 = NR2..00 / MR2..00 * 100.
COMPUTE NR2.2.00 = NR2.2.00 / MR2.2.00 * 100.
EXECUTE.
DELETE VARIABLES MR2..00 MR2.2.00.

DELETE VARIABLES Imitator.
RENAME VARIABLES Model = Subject.


T-TEST PAIRS=RT1..00 R1_Duration..00 NR1..00 RT2..00 R2_Duration..00 NR2..00 WITH RT1.2.00 
    R1_Duration.2.00 NR1.2.00 RT2.2.00 R2_Duration.2.00 NR2.2.00 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

Formats
Subject
RT1..00
RT1.2.00
R1_Duration..00
R1_Duration.2.00
NR1..00
NR1.2.00
RT2..00
RT2.2.00
R2_Duration..00
R2_Duration.2.00
NR2..00
NR2.2.00 (F16.10).




