* Encoding: UTF-8.
* Note: Replace "...PATH..." with the path to the logfile!.
GET DATA
  /TYPE=TXT
  /FILE="...PATH...\Pfister_et_al_2013_PsySci_Exp2_Raw.dat"
  /DELCASE=LINE
  /DELIMITERS="\t"
  /ARRANGEMENT=DELIMITED
  /FIRSTCASE=2
  /IMPORTCASE=ALL
  /VARIABLES=
  Participant_Pair F2.0
  Model F2.0
  Imitator F2.0
  Part F1.0
  Block F1.0
  Blocktrial F2.0
  Trial F3.0
  Compatibility F2.0
  RT1 F4.0
  R1_CDuration F1.0
  R1_Duration F3.0
  R1_ACC F1.0
  R1_ErrorType F3.0
  RT2 F3.0
  RT2_Cor F4.0
  R2_CDuration F1.0
  R2_Duration F3.0
  R2_ACC F3.0
  R2_ErrorType F3.0
  Trial_ACC F1.0
  Trial_ACC_N1 F3.0.
CACHE.
EXECUTE.
DATASET NAME SozRE WINDOW=FRONT.


*Set RT and error filters.
USE ALL.
COMPUTE errorfilter1=((Block ~= 1) & (Block ~= 6) & (Block ~= 11) & (Block ~= 16) & (R1_Duration > 0)).
VALUE LABELS errorfilter1 0 'Not Selected' 1 'Selected'.
FORMATS errorfilter1 (f1.0).
FILTER BY errorfilter1.
EXECUTE.


USE ALL.
COMPUTE megafilter=((Block ~= 1) & (Block ~= 6) & (Block ~= 11) & (Block ~= 16) & (Trial_ACC = 1) & (Compatibility ~= -99) & (R1_Duration > 0)).
VALUE LABELS megafilter 0 'Not Selected' 1 'Selected'.
FORMATS megafilter (f1.0).
FILTER BY megafilter.
EXECUTE.


DELETE VARIABLES ZRT1 ZR1_Duration ZRT2 ZR2_Duration.
SORT CASES  BY Model Compatibility.
SPLIT FILE SEPARATE BY Model Compatibility.


DESCRIPTIVES VARIABLES=RT1 R1_Duration RT2 R2_Duration
  /SAVE
  /STATISTICS=MEAN STDDEV MIN MAX.


SPLIT FILE OFF.
SORT CASES BY Participant_Pair(A) Model(A) Part(A) Block(A) Blocktrial(A).



************************************************************************************************************************************************************************.
* Get model R-E data ***********************************************************************************************************************************************.
************************************************************************************************************************************************************************.

USE ALL.
COMPUTE zfilter=((megafilter = 1) & (ABS(ZRT1)<2.5)).
VALUE LABELS zfilter 0 'Not Selected' 1 'Selected'.
FORMATS zfilter (f1.0).
FILTER BY zfilter.
EXECUTE.

DATASET DECLARE Soz_RE_Aggr.
AGGREGATE
  /OUTFILE='Soz_RE_Aggr'
  /BREAK=Model Compatibility
  /RT1=MEAN(RT1) 
  /R1_Duration=MEAN(R1_Duration) .

DATASET ACTIVATE Soz_RE_Aggr.

COMPUTE Compatibility_Corr = Compatibility + 1.
EXECUTE.

COMPUTE Compatibility_Corr = Compatibility_Corr * 2.
EXECUTE.


SORT CASES BY Model Compatibility_Corr.
CASESTOVARS
  /ID=Model
  /INDEX=Compatibility_Corr
  /GROUPBY=VARIABLE.

COMPUTE MeanUnpred=(RT1.1.00 + RT1.3.00) / 2.
EXECUTE.

T-TEST PAIRS=RT1.1.00 MeanUnpred WITH RT1.3.00 RT1.4.00 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

T-TEST PAIRS=RT1.1.00 RT1.3.00 WITH RT1.3.00 RT1.4.00 (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.





************************************************************************************************************************************************************************.
* Get model R-E data: errors ***************************************************************************************************************************************.
************************************************************************************************************************************************************************.
DATASET ACTIVATE SozRE.

USE ALL.
COMPUTE zfilter=((errorfilter1 = 1) & (R1_ACC = 0)).
VALUE LABELS zfilter 0 'Not Selected' 1 'Selected'.
FORMATS zfilter (f1.0).
FILTER BY zfilter.
EXECUTE.

DATASET DECLARE Soz_RE_Aggr_tmp.
AGGREGATE
  /OUTFILE='Soz_RE_Aggr_tmp'
  /BREAK=Model Compatibility
  /NR1=N(RT1).

DATASET ACTIVATE Soz_RE_Aggr_tmp.


COMPUTE Compatibility_Corr = Compatibility + 100.
EXECUTE. 

RECODE Compatibility_Corr (99.5=99) (100.5=100).
EXECUTE.


SORT CASES BY Model Compatibility_Corr.
CASESTOVARS
  /ID=Model
  /INDEX=Compatibility_Corr
  /GROUPBY=VARIABLE.

RECODE NR1.1.00 NR1.101.00 (MISSING=0).
EXECUTE.


DATASET ACTIVATE Soz_RE_Aggr.

MATCH FILES /FILE=*
  /FILE='Soz_RE_Aggr_tmp'
  /RENAME (Compatibility.1.00 Compatibility.101.00 = d2 d3) 
  /DROP= d2 d3.
EXECUTE.

DATASET CLOSE Soz_RE_Aggr_tmp.




************************************************************************************************************************************************************************.
* Get model R-E data: Nerrors *************************************************************************************************************************************.
************************************************************************************************************************************************************************.
DATASET ACTIVATE SozRE.

USE ALL.
COMPUTE zfilter=((errorfilter1 = 1)).
VALUE LABELS zfilter 0 'Not Selected' 1 'Selected'.
FORMATS zfilter (f1.0).
FILTER BY zfilter.
EXECUTE.

DATASET DECLARE Soz_RE_Aggr_tmp.
AGGREGATE
  /OUTFILE='Soz_RE_Aggr_tmp'
  /BREAK=Model Compatibility
  /MR1=N(RT1).

DATASET ACTIVATE Soz_RE_Aggr_tmp.

COMPUTE Compatibility_Corr = Compatibility + 100.
EXECUTE. 


RECODE Compatibility_Corr (99.5=99) (100.5=100).
EXECUTE.


SORT CASES BY Model Compatibility_Corr.
CASESTOVARS
  /ID=Model
  /INDEX=Compatibility_Corr
  /GROUPBY=VARIABLE.

COMPUTE MR1.1.00=MR1.1.00 + MR1.99.00 + MR1.100.00.
EXECUTE.

DELETE VARIABLES Compatibility.99.00 Compatibility.100.00.
DELETE VARIABLES Compatibility.1.00 Compatibility.101.00.
DELETE VARIABLES MR1.99.00 MR1.100.00.
EXECUTE.


DATASET ACTIVATE Soz_RE_Aggr.

MATCH FILES /FILE=*
  /FILE='Soz_RE_Aggr_tmp'.
EXECUTE.


DATASET CLOSE Soz_RE_Aggr_tmp.











************************************************************************************************************************************************************************.
* Clean up dataset **************************************************************************************************************************************************.
************************************************************************************************************************************************************************.
DATASET ACTIVATE Soz_RE_Aggr.

COMPUTE NR1.1.00 = NR1.1.00 / MR1.1.00 * 100.
COMPUTE NR1.101.00 = NR1.101.00 / MR1.101.00 * 100.
EXECUTE.
DELETE VARIABLES MR1.1.00 MR1.101.00.
DELETE VARIABLES Compatibility.1.00 Compatibility.3.00 Compatibility.4.00.
DELETE VARIABLES R1_Duration.1.00 R1_Duration.3.00 R1_Duration.4.00.

RENAME VARIABLES Model = Subject.
RENAME VARIABLES RT1.1.00 = RT_UnpredIncomp.
RENAME VARIABLES RT1.3.00 = RT_Unpred_Comp.
RENAME VARIABLES RT1.4.00 = RT_Compatible.
RENAME VARIABLES MeanUnpred = RT_Unpred_Mean.
RENAME VARIABLES NR1.1.00 = PE_Unpred.
RENAME VARIABLES NR1.101.00 = PE_Compatible.

FORMATS PE_Unpred PE_Compatible (f8.4).


T-TEST PAIRS=RT_UnpredIncomp RT_Unpred_Comp RT_Unpred_Mean PE_Unpred WITH RT_Unpred_Comp 
    RT_Compatible RT_Compatible PE_Compatible (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


